import axios, { AxiosResponse } from "axios";
import { getToken, removeToken } from "./auth";
import type { MessageApiInjection } from "naive-ui/es/message/src/MessageProvider";
import type { Router } from "vue-router";

let message: MessageApiInjection = null;
let router: Router = null;
export function setupResponseInterceptors({ message: msg, router: rt }: {
  message: MessageApiInjection;
  router: Router;
}) {
  message = msg;
  router = rt;
}

// 定义后端返回的统一数据结构
interface ApiResponse<T = any> {
  code: number;
  data: T;
  msg: string;
}

const instance = axios.create({
  baseURL: import.meta.env.VITE_API_BASE_URL as string, // 从 Vite 环境变量获取 baseURL
  timeout: 10000, // 请求超时时间
  headers: {
    "Content-Type": "application/json",
  },
});

// 请求拦截器
instance.interceptors.request.use(
  (config) => {
    // 添加 token 等请求头
    const token = getToken();
    if (token) {
      config.headers.Authorization = `Bearer ${token}`;
    }
    return config;
  },
  (error) => {
    return Promise.reject(error);
  }
);

// 响应拦截器
instance.interceptors.response.use(
  (response: AxiosResponse<ApiResponse>) => {
    const { code, msg } = response.data;

    // 401 未授权，跳转首页
    if (code === 401) {
      // // 这里调用退出登录的逻辑
      message.error("未授权，跳转首页");
      // // 清除用户信息
      removeToken();
      // // 跳转首页
      router.push('/');
      return Promise.reject(new Error(msg || "未授权"));
    }

    // 其他非 200 状态码
    if (code !== 200) {
      console.error(`请求错误 ${code}: ${msg}`);
      // 这里可以根据需要弹出错误提示
      return Promise.reject(new Error(msg || "请求错误"));
    }

    // 返回数据部分
    return response.data.data;
  },
  (error) => {
    // 处理 HTTP 状态码不是 200 的情况
    if (error.response) {
      const { status, data } = error.response;
      console.error(`HTTP 错误 ${status}:`, data);
    } else {
      console.error("请求错误:", error.message);
    }
    return Promise.reject(error);
  }
);

export default instance;
